@@ -8,8 +8,8 @@
 ;; URL: https://github.com/dimitri/switch-window
 ;;      http://tapoueh.org/emacs/switch-window.html
 ;; Git-URL: https://github.com/dimitri/switch-window.git
-;; Package-Version: 20250401.839
-;; Package-Revision: 8f771b571a1e
+;; Package-Version: 20260225.115
+;; Package-Revision: a72cf11d21c1
 ;; Created: 2010-04-30
 ;; Keywords: convenience
 ;; Licence: WTFPL, grab your copy here: http://sam.zoy.org/wtfpl/
@@ -223,6 +223,7 @@
 
 (require 'cl-lib)
 (require 'quail)
+(require 'window)
 (require 'switch-window-asciiart)
 (require 'switch-window-mvborder)
 
@@ -412,7 +413,7 @@ This function is used when `switch-window-multiple-frames' is non-nil."
 windows from all frames. Call `other-window' otherwise."
   (if switch-window-multiple-frames
       (switch-window--select-window (next-window nil nil 'visible))
-    (other-window 1)))
+    (select-window (next-window nil nil 'visible))))
 
 (defun switch-window--select-window (window)
   "Switch to the window WINDOW. Select WINDOW's frame respecting
@@ -691,8 +692,7 @@ won't take effect, and no buffers will be switched."
           (progn
             (select-window window1)
             (message "The selected window has a dedicated buffer: `%s'" (buffer-name buffer2)))
-        (set-window-buffer window2 buffer1 t)
-        (set-window-buffer window1 buffer2 t)
+        (window-swap-states window1 window2)
         (if keep-focus
             (switch-window--select-window window1))))))
 
